import { DependencyList } from 'react';
import { PartialKey } from '@proscom/prostore';
import { IAxiosQueryOptions, IAxiosQueryStoreParams } from '@proscom/prostore-axios';
import { UseRequestOptions } from '@proscom/prostore-react';
import { AxiosInstance } from 'axios';
export declare type IUseAxiosQueryOptions<Vars, Data> = PartialKey<IAxiosQueryStoreParams<Vars, Data>, 'client'>;
export interface IUseAxiosQueryParams<Vars, Data> {
    /** Axios Client instance to be used for data fetching, or its name for it to be injected from the context */
    client?: string | AxiosInstance;
    /** Query specification */
    queryOptions?: IUseAxiosQueryOptions<Vars, Data>;
    /** Query variables */
    variables?: Vars;
    /** Additional query options */
    options?: IAxiosQueryOptions<Vars, Data>;
    /** Additional hook options */
    hookOptions?: UseRequestOptions<Vars, Data>;
}
/**
 * Creates AxiosQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the axios based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
export declare function useAxiosQuery<Vars, Data>({ client, queryOptions, variables, options, hookOptions }: IUseAxiosQueryParams<Vars, Data>): import("@proscom/prostore-react").UseRequestStoreResult<import("@proscom/prostore").IRequestState<Vars, Data>>;
export interface IUseAxiosQueryVarsParams<Vars, Data> extends IUseAxiosQueryParams<Vars, Data> {
    variableCreator: [() => Vars, DependencyList];
}
/**
 * The same as useAxiosQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 */
export declare function useAxiosQueryVars<Vars, Data>({ variableCreator, ...queryProps }: IUseAxiosQueryVarsParams<Vars, Data>): import("@proscom/prostore-react").UseRequestStoreResult<import("@proscom/prostore").IRequestState<Vars, Data>>;
